@@ -164,6 +164,7 @@ print_domain_name(const ProtobufCBinaryData *domain, FILE *fp)
 {
 	/* Wrap the binary data in 'domain' into an 'ldns_rdf'. */
 	ldns_rdf *dname;
+	assert(domain->data != NULL);
 	dname = ldns_dname_new(domain->len, domain->data);
 	if (!dname)
 		return false;
@@ -179,7 +180,7 @@ print_domain_name(const ProtobufCBinaryData *domain, FILE *fp)
 }
 
 static bool
-print_ip_address(const ProtobufCBinaryData *ip, FILE *fp)
+print_ip_address(const ProtobufCBinaryData *ip, FILE *fp, const bool do_quote)
 {
 	char buf[INET6_ADDRSTRLEN] = {0};
 
@@ -197,7 +198,13 @@ print_ip_address(const ProtobufCBinaryData *ip, FILE *fp)
 	}
 
 	/* Print the presentation form of the IP address. */
-	fputs(buf, fp);
+	if (do_quote) {
+		fputc('"', fp);
+		fputs(buf, fp);
+		fputc('"', fp);
+	} else {
+		fputs(buf, fp);
+	}
 
 	/* Success. */
 	return true;
@@ -319,12 +326,12 @@ print_dnstap_message_quiet(const Dnstap__Message *m, FILE *fp)
 	}
 	if (print_query_address) {
 		if (m->has_query_address)
-			print_ip_address(&m->query_address, fp);
+			print_ip_address(&m->query_address, fp, false);
 		else
 			fputs("MISSING_ADDRESS", fp);
 	} else {
 		if (m->has_response_address)
-			print_ip_address(&m->response_address, fp);
+			print_ip_address(&m->response_address, fp, false);
 		else
 			fputs("MISSING_ADDRESS", fp);
 	}
@@ -428,14 +435,14 @@ print_dnstap_message_yaml(const Dnstap__Message *m, FILE *fp)
 	/* Print 'query_address' field. */
 	if (m->has_query_address) {
 		fputs("  query_address: ", fp);
-		print_ip_address(&m->query_address, fp);
+		print_ip_address(&m->query_address, fp, true);
 		fputc('\n', fp);
 	}
 
 	/* Print 'response_address field. */
 	if (m->has_response_address) {
 		fputs("  response_address: ", fp);
-		print_ip_address(&m->response_address, fp);
+		print_ip_address(&m->response_address, fp, true);
 		fputc('\n', fp);
 	}
 
@@ -448,7 +455,7 @@ print_dnstap_message_yaml(const Dnstap__Message *m, FILE *fp)
 		fprintf(fp, "  response_port: %u\n", m->response_port);
 
 	/* Print 'query_zone' field. */
-	if (m->has_query_zone) {
+	if (m->has_query_zone && m->query_zone.data != NULL) {
 		fputs("  query_zone: ", fp);
 		print_domain_name(&m->query_zone, fp);
 		fputc('\n', fp);
@@ -513,7 +520,7 @@ print_dnstap_frame_yaml(const Dnstap__Dnstap *d, FILE *fp)
 	}
 
 	/* Print 'message' field. */
-	if (d->type == DNSTAP__DNSTAP__TYPE__MESSAGE) {
+	if (d->type == DNSTAP__DNSTAP__TYPE__MESSAGE && d->message != NULL) {
 		fputs("message:\n", fp);
 		if (!print_dnstap_message_yaml(d->message, fp))
 			return false;
@@ -697,6 +704,8 @@ read_input_hex(const char *input_fname,
 {
 	int rv = EXIT_FAILURE;
 	FILE *r = NULL;
+	ldns_rdf *rdf = NULL;
+	ldns_rr *rr = NULL;
 
 	/* Allocate buffer for input data. */
 	static const size_t alloc_bytes = 262144;
@@ -742,8 +751,6 @@ read_input_hex(const char *input_fname,
 	}
 
 	/* Unhexlify the data. */
-	ldns_rdf *rdf = NULL;
-	ldns_rr *rr = NULL;
 	ldns_status status = ldns_str2rdf_hex(&rdf, p);
 	if (status != LDNS_STATUS_OK) {
 		/**
@@ -777,7 +784,7 @@ read_input_hex(const char *input_fname,
 		}
 
 		if (ldns_rr_rd_count(rr) != 1) {
-			fprintf(stderr, "Error: Unexpected rdf count (%u).\n",
+			fprintf(stderr, "Error: Unexpected rdf count (%zu).\n",
 				ldns_rr_rd_count(rr));
 			goto out;
 		}
